#[repr(transparent)]pub struct RemovableRow {
inner: TypedObjectRef<RemovableRow, <RemovableRow as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
An AdwActionRow with a “remove” button.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<RemovableRow, <RemovableRow as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl RemovableRow
impl RemovableRow
The tooltip text of the remove button.
The tooltip text of the remove button.
The accessible label of the remove button.
The accessible label of the remove button.
Sourcepub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
pub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
Whether this row is loading.
Sourcepub fn set_is_loading<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_loading<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this row is loading.
Sourcepub fn extra_suffix(&self) -> <PhantomData<Option<Widget>> as Property>::Value
pub fn extra_suffix(&self) -> <PhantomData<Option<Widget>> as Property>::Value
The extra suffix widget of this row.
The widget is placed before the remove button.
Sourcepub fn set_extra_suffix<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_extra_suffix<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>, )
The extra suffix widget of this row.
The widget is placed before the remove button.
Listen for notifications of a change in the remove-button-tooltip-text property
Listen for notifications of a change in the remove-button-accessible-label property
Sourcepub fn connect_is_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-loading property
Sourcepub fn connect_extra_suffix_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_extra_suffix_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the extra-suffix property
Notify listeners of a change in the remove-button-tooltip-text property
Notify listeners of a change in the remove-button-accessible-label property
Sourcepub fn notify_is_loading(&self)
pub fn notify_is_loading(&self)
Notify listeners of a change in the is-loading property
Sourcepub fn notify_extra_suffix(&self)
pub fn notify_extra_suffix(&self)
Notify listeners of a change in the extra-suffix property
Sourceimpl RemovableRow
impl RemovableRow
pub fn new() -> Self
Sourcepub fn connect_remove<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_remove<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Connect to the remove signal.